==> kinetophone-0.2.0.tar.gz: kinetophone-0.2.0/src/narrator/Kinetophone_dir_slide_collection.hpp <==
// Kinetophone_dir_slide_collection.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef KINETOPHONE_DIR_SLIDE_COLLECTION_HPP_
#define KINETOPHONE_DIR_SLIDE_COLLECTION_HPP_

#include "../base/Dir_slide_collection.hpp"
#include <string>
#include <vector>

namespace Gdk
{
  class Pixbuf;
}

namespace Glib
{
  template <class T> class RefPtr;
}

namespace xmlpp
{
  class Node;
}

using std::string;
using std::vector;
using Gdk::Pixbuf;
using Glib::RefPtr;
using xmlpp::Node;

namespace Roan_trail
{
  class Error;
  class Error_param;

  using Source::Dir_slide_collection;

  namespace Kinetophone
  {
    class Kinetophone_dir_slide_collection : public Dir_slide_collection<RefPtr<Pixbuf> >
    {
    public:
      // constructor/destructor
      Kinetophone_dir_slide_collection()
        : Dir_slide_collection<RefPtr<Pixbuf> >() {}
      // accessors
      virtual void image_for_slide_at(int slide_index, RefPtr<Pixbuf>& return_image) const;
      virtual void thumbnail_for_slide_at(int slide_index, RefPtr<Pixbuf>& return_image) const;
      virtual Rect_size max_bounds() const;
    protected:
      // invariant check
      bool mf_invariant(bool check_base_class = true) const;
      //
      virtual bool mf_process_source_images_with_notes(const vector<string>& image_paths,
                                                       const string& source_path,
                                                       Error_param& return_error);
    private:
      // prevent compiler from generating
      Kinetophone_dir_slide_collection(const Kinetophone_dir_slide_collection& dir_slide_collection);
      Kinetophone_dir_slide_collection& operator=(const Kinetophone_dir_slide_collection& dir_slide_collection);
    };
  }
}

#endif // KINETOPHONE_DIR_SLIDE_COLLECTION_HPP_

==> kinetophone-0.3.0.tar.gz: kinetophone-0.3.0/src/narrator/Kinetophone_dir_slide_collection.hpp <==
// Kinetophone_dir_slide_collection.hpp
//
// Copyright 2011-2012 Roan Trail, Inc.
//
// This file is part of Kinetophone.
//
// Kinetophone is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published
// by the Free Software Foundation, either version 2 of the License,
// or (at your option) any later version.
//
// Kinetophone is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.  You should have received
// a copy of the GNU General Public License along with Kinetophone. If
// not, see <http://www.gnu.org/licenses/>.

#ifndef KINETOPHONE_DIR_SLIDE_COLLECTION_HPP_
#define KINETOPHONE_DIR_SLIDE_COLLECTION_HPP_

#include <gdkmm/pixbuf.h> // Dir_slide_collection.hpp needs this included first
#include "../base/Dir_slide_collection.hpp"
#include <string>
#include <vector>

namespace Gdk
{
  class Pixbuf;
}

namespace Glib
{
  template <class T> class RefPtr;
}

namespace Roan_trail
{
  class Error_param;

  namespace Kinetophone
  {
    class Kinetophone_dir_slide_collection
      : public Roan_trail::Source::Dir_slide_collection<Glib::RefPtr<Gdk::Pixbuf> >
    {
    public:
      // constructor/destructor
      Kinetophone_dir_slide_collection()
        : Roan_trail::Source::Dir_slide_collection<Glib::RefPtr<Gdk::Pixbuf> >() {}
      // accessors
      virtual bool image_for_slide_at(int slide_index, Glib::RefPtr<Gdk::Pixbuf>& return_image) const;
      virtual void thumbnail_for_slide_at(int slide_index, Glib::RefPtr<Gdk::Pixbuf>& return_image) const;
      virtual Rect_size max_bounds() const;
    protected:
      // invariant check
      bool mf_invariant(bool check_base_class = true) const;
      //
      virtual bool mf_process_source_images_with_notes(const std::vector<std::string>& image_paths,
                                                       const std::string& source_path,
                                                       Error_param& return_error);
    private:
      // prevent compiler from generating
      Kinetophone_dir_slide_collection(const Kinetophone_dir_slide_collection& dir_slide_collection);
      Kinetophone_dir_slide_collection& operator=(const Kinetophone_dir_slide_collection& dir_slide_collection);
    };
  }
}

#endif // KINETOPHONE_DIR_SLIDE_COLLECTION_HPP_
